@@ -1333,9 +1333,10 @@ and (queue=0 or (queue=2 and due<=?))""",
 
     def forgetCards(self, ids):
         "Put cards at the end of the new queue."
+        self.remFromDyn(ids)
         self.col.db.execute(
-            "update cards set type=0,queue=0,ivl=0,due=0,factor=? where odid=0 "
-            "and queue >= 0 and id in "+ids2str(ids), 2500)
+            "update cards set type=0,queue=0,ivl=0,due=0,odue=0,factor=?"
+            " where id in "+ids2str(ids), 2500)
         pmax = self.col.db.scalar(
             "select max(due) from cards where type=0") or 0
         # takes care of mod + usn
@@ -1351,10 +1352,10 @@ and (queue=0 or (queue=2 and due<=?))""",
             r = random.randint(imin, imax)
             d.append(dict(id=id, due=r+t, ivl=max(1, r), mod=mod,
                           usn=self.col.usn(), fact=2500))
-        self.removeLrn(ids)
+        self.remFromDyn(ids)
         self.col.db.executemany("""
-update cards set type=2,queue=2,ivl=:ivl,due=:due,
-usn=:usn, mod=:mod, factor=:fact where id=:id and odid=0 and queue >=0""",
+update cards set type=2,queue=2,ivl=:ivl,due=:due,odue=0,
+usn=:usn,mod=:mod,factor=:fact where id=:id""",
                                 d)
         self.col.log(ids)
 
