@@ -3,9 +3,12 @@
 # License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
 
 from __future__ import division
-import    difflib, re, cgi
+import difflib
+import re
+import cgi
 import unicodedata as ucd
 import HTMLParser
+
 from anki.lang import _, ngettext
 from aqt.qt import *
 from anki.utils import  stripHTML, isMac, json
@@ -15,6 +18,7 @@ from aqt.utils import mungeQA, getBase, openLink, tooltip, askUserDialog
 from aqt.sound import getAudio
 import aqt
 
+
 class Reviewer(object):
     "Manage reviews.  Maintains a separate state."
 
@@ -191,7 +195,7 @@ function _typeAnsPress() {
         # grab the question and play audio
         if c.isEmpty():
             q = _("""\
-The front of this card is empty. Please run Tools>Maintenance>Empty Cards.""")
+The front of this card is empty. Please run Tools>Empty Cards.""")
         else:
             q = c.q()
         if self.autoplay(c):
@@ -285,8 +289,10 @@ The front of this card is empty. Please run Tools>Maintenance>Empty Cards.""")
             self.replayAudio()
         elif key == "*":
             self.onMark()
-        elif key == "-":
+        elif key == "=":
             self.onBuryNote()
+        elif key == "-":
+            self.onBuryCard()
         elif key == "!":
             self.onSuspend()
         elif key == "@":
@@ -437,7 +443,11 @@ Please run Tools>Empty Cards""")
         # compare in NFC form so accents appear correct
         given = ucd.normalize("NFC", given)
         correct = ucd.normalize("NFC", correct)
-        s = difflib.SequenceMatcher(None, given, correct, autojunk=False)
+        try:
+            s = difflib.SequenceMatcher(None, given, correct, autojunk=False)
+        except:
+            # autojunk was added in python 2.7.1
+            s = difflib.SequenceMatcher(None, given, correct)
         givenElems = []
         correctElems = []
         givenPoint = 0
@@ -468,11 +478,11 @@ Please run Tools>Empty Cards""")
         "Diff-corrects the typed-in answer."
         givenElems, correctElems = self.tokenizeComparison(given, correct)
         def good(s):
-            return "<span class=typeGood>"+s+"</span>"
+            return "<span class=typeGood>"+cgi.escape(s)+"</span>"
         def bad(s):
-            return "<span class=typeBad>"+s+"</span>"
+            return "<span class=typeBad>"+cgi.escape(s)+"</span>"
         def missed(s):
-            return "<span class=typeMissed>"+s+"</span>"
+            return "<span class=typeMissed>"+cgi.escape(s)+"</span>"
         if given == correct:
             res = good(given)
         else:
@@ -674,7 +684,8 @@ function showAnswer(txt) {
     def showContextMenu(self):
         opts = [
             [_("Mark Note"), "*", self.onMark],
-            [_("Bury Note"), "-", self.onBuryNote],
+            [_("Bury Card"), "-", self.onBuryCard],
+            [_("Bury Note"), "=", self.onBuryNote],
             [_("Suspend Card"), "@", self.onSuspendCard],
             [_("Suspend Note"), "!", self.onSuspend],
             [_("Delete Note"), "Delete", self.onDelete],
@@ -693,6 +704,7 @@ function showAnswer(txt) {
             a = m.addAction(label)
             a.setShortcut(QKeySequence(scut))
             a.connect(a, SIGNAL("triggered()"), func)
+        runHook("Reviewer.contextMenuEvent",self,m)
         m.exec_(QCursor.pos())
 
     def onOptions(self):
@@ -735,6 +747,12 @@ function showAnswer(txt) {
             "Note and its %d cards deleted.",
             cnt) % cnt)
 
+    def onBuryCard(self):
+        self.mw.checkpoint(_("Bury"))
+        self.mw.col.sched.buryCards([self.card.id])
+        self.mw.reset()
+        tooltip(_("Card buried."))
+
     def onBuryNote(self):
         self.mw.checkpoint(_("Bury"))
         self.mw.col.sched.buryNote(self.card.nid)
